@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2020-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2020-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -53,7 +53,10 @@ void testing_syr2k_batched_bad_arg(const Arguments& arg)
         const int64_t           ldc         = 100;
         int64_t                 batch_count = 2;
 
-        device_vector<T> alpha_d(1), beta_d(1), one_d(1), zero_d(1);
+        DEVICE_MEMCHECK(device_vector<T>, alpha_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, beta_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, one_d, (1));
+        DEVICE_MEMCHECK(device_vector<T>, zero_d, (1));
 
         const T alpha_h(1), beta_h(2), one_h(1), zero_h(0);
 
@@ -78,14 +81,9 @@ void testing_syr2k_batched_bad_arg(const Arguments& arg)
         size_t cols = (transA == rocblas_operation_none ? std::max(K, int64_t(1)) : N);
 
         // Allocate device memory
-        device_batch_matrix<T> dA(rows, cols, lda, batch_count);
-        device_batch_matrix<T> dB(rows, cols, ldb, batch_count);
-        device_batch_matrix<T> dC(N, N, ldc, batch_count);
-
-        // Check device memory allocation
-        CHECK_DEVICE_ALLOCATION(dA.memcheck());
-        CHECK_DEVICE_ALLOCATION(dB.memcheck());
-        CHECK_DEVICE_ALLOCATION(dC.memcheck());
+        DEVICE_MEMCHECK(device_batch_matrix<T>, dA, (rows, cols, lda, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<T>, dB, (rows, cols, ldb, batch_count));
+        DEVICE_MEMCHECK(device_batch_matrix<T>, dC, (N, N, ldc, batch_count));
 
         DAPI_EXPECT(
             rocblas_status_invalid_handle,
@@ -337,36 +335,23 @@ void testing_syr2k_batched(const Arguments& arg)
 
     // Naming: `h` is in CPU (host) memory(eg hA), `d` is in GPU (device) memory (eg dA).
     // Allocate host memory
-    host_batch_matrix<T> hA(rows, cols, lda, batch_count);
-    host_batch_matrix<T> hB(rows, cols, ldb, batch_count);
-    host_batch_matrix<T> hC(N, N, ldc, batch_count);
-    host_batch_matrix<T> hC_gold(N, N, ldc, batch_count);
-    host_vector<T>       h_alpha(1);
-    host_vector<T>       h_beta(1);
-
-    // Check host memory allocation
-    CHECK_HIP_ERROR(hA.memcheck());
-    CHECK_HIP_ERROR(hB.memcheck());
-    CHECK_HIP_ERROR(hC.memcheck());
-    CHECK_HIP_ERROR(hC_gold.memcheck());
+    HOST_MEMCHECK(host_batch_matrix<T>, hA, (rows, cols, lda, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<T>, hB, (rows, cols, ldb, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<T>, hC, (N, N, ldc, batch_count));
+    HOST_MEMCHECK(host_batch_matrix<T>, hC_gold, (N, N, ldc, batch_count));
+    HOST_MEMCHECK(host_vector<T>, h_alpha, (1));
+    HOST_MEMCHECK(host_vector<T>, h_beta, (1));
 
     // Initial Data on CPU
     h_alpha[0] = alpha;
     h_beta[0]  = beta;
 
     // Allocate device memory
-    device_batch_matrix<T> dA(rows, cols, lda, batch_count);
-    device_batch_matrix<T> dB(rows, cols, ldb, batch_count);
-    device_batch_matrix<T> dC(N, N, ldc, batch_count);
-    device_vector<T>       d_alpha(1);
-    device_vector<T>       d_beta(1);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(dA.memcheck());
-    CHECK_DEVICE_ALLOCATION(dB.memcheck());
-    CHECK_DEVICE_ALLOCATION(dC.memcheck());
-    CHECK_DEVICE_ALLOCATION(d_alpha.memcheck());
-    CHECK_DEVICE_ALLOCATION(d_beta.memcheck());
+    DEVICE_MEMCHECK(device_batch_matrix<T>, dA, (rows, cols, lda, batch_count));
+    DEVICE_MEMCHECK(device_batch_matrix<T>, dB, (rows, cols, ldb, batch_count));
+    DEVICE_MEMCHECK(device_batch_matrix<T>, dC, (N, N, ldc, batch_count));
+    DEVICE_MEMCHECK(device_vector<T>, d_alpha, (1));
+    DEVICE_MEMCHECK(device_vector<T>, d_beta, (1));
 
     // Initialize data on host memory
     rocblas_init_matrix(hA, arg, rocblas_client_never_set_nan, rocblas_client_general_matrix, true);
@@ -441,11 +426,12 @@ void testing_syr2k_batched(const Arguments& arg)
                         batch_count));
             if(arg.repeatability_check)
             {
-                host_batch_matrix<T> hC_copy(N, N, ldc, batch_count);
+                HOST_MEMCHECK(host_batch_matrix<T>, hC_copy, (N, N, ldc, batch_count));
                 CHECK_HIP_ERROR(hC.transfer_from(dC));
                 // multi-GPU support
                 int device_id, device_count;
-                CHECK_HIP_ERROR(hipGetDeviceCount(&device_count));
+                CHECK_HIP_ERROR(limit_device_count(device_count, (int)arg.devices));
+
                 for(int dev_id = 0; dev_id < device_count; dev_id++)
                 {
                     CHECK_HIP_ERROR(hipGetDevice(&device_id));
@@ -456,18 +442,13 @@ void testing_syr2k_batched(const Arguments& arg)
                     rocblas_local_handle handle_copy{arg};
 
                     //Allocate device memory in new device
-                    device_batch_matrix<T> dA_copy(rows, cols, lda, batch_count);
-                    device_batch_matrix<T> dB_copy(rows, cols, ldb, batch_count);
-                    device_batch_matrix<T> dC_copy(N, N, ldc, batch_count);
-                    device_vector<T>       d_alpha_copy(1);
-                    device_vector<T>       d_beta_copy(1);
-
-                    // Check device memory allocation
-                    CHECK_DEVICE_ALLOCATION(dA_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dB_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dC_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(d_alpha_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(d_beta_copy.memcheck());
+                    DEVICE_MEMCHECK(
+                        device_batch_matrix<T>, dA_copy, (rows, cols, lda, batch_count));
+                    DEVICE_MEMCHECK(
+                        device_batch_matrix<T>, dB_copy, (rows, cols, ldb, batch_count));
+                    DEVICE_MEMCHECK(device_batch_matrix<T>, dC_copy, (N, N, ldc, batch_count));
+                    DEVICE_MEMCHECK(device_vector<T>, d_alpha_copy, (1));
+                    DEVICE_MEMCHECK(device_vector<T>, d_beta_copy, (1));
 
                     // copy data from CPU to device
                     CHECK_HIP_ERROR(dA_copy.transfer_from(hA));
