@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,8 +22,9 @@
 
 #ifndef ROCBLAS_BETA_H
 #define ROCBLAS_BETA_H
-#include "rocblas-auxiliary.h"
+
 #include "rocblas-export.h"
+#include "rocblas-macros.h"
 #include "rocblas-types.h"
 
 /*!\file
@@ -558,8 +559,8 @@ ROCBLAS_EXPORT rocblas_status
 //! @}
 
 ROCBLAS_DEPRECATED_MSG(
-    "rocblas_gemm_ex3 is a beta feature and is subject to change in future releases."
-    "Trying to run this API on unsupported hardware will return rocblas_status_arch_mismatch ")
+    "rocblas_gemm_ex3 is deprecated and it will be removed in the next major release of rocBLAS."
+    "Please refer to hipBLASLT for future 8 bit float usage https://github.com/ROCm/hipBLASLt")
 /*! @{
     \brief <b> BLAS BETA API </b>
 
@@ -707,6 +708,10 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_ex3(rocblas_handle      handle,
                                                uint32_t            flags);
 //! @}
 
+ROCBLAS_DEPRECATED_MSG(
+    "gemm_strided_batched_ex3 is deprecated and it will be removed in the next major release of "
+    "rocBLAS."
+    "Please refer to hipBLASLT for future 8 bit float usage https://github.com/ROCm/hipBLASLt")
 /*! @{
     \brief <b> BLAS EX API </b>
 
@@ -884,6 +889,10 @@ ROCBLAS_EXPORT rocblas_status rocblas_gemm_strided_batched_ex3(rocblas_handle
                                                                uint32_t            flags);
 //! @}
 
+ROCBLAS_DEPRECATED_MSG(
+    "gemm_batched_ex3 is deprecated and it will be removed in the next major release of "
+    "rocBLAS."
+    "Please refer to hipBLASLT for future 8 bit float usage https://github.com/ROCm/hipBLASLt")
 /*! @{
     \brief <b> BLAS BETA API </b>
 
