@@ -49,14 +49,6 @@ namespace
             return rocblas_status_invalid_handle;
         }
 
-        if constexpr(std::is_same_v<API_INT, int>)
-        {
-            if(batch_count > c_YZ_grid_launch_limit && handle->isYZGridDim16bit())
-            {
-                return rocblas_status_invalid_size;
-            }
-        }
-
         size_t dev_bytes = rocblas_reduction_workspace_size<API_INT, ROCBLAS_DOT_NB>(
             n, incx, incy, batch_count, execution_type);
         if(handle->is_device_memory_size_query())
@@ -67,7 +59,8 @@ namespace
                 return handle->set_optimal_device_memory_size(dev_bytes);
         }
 
-        auto layer_mode = handle->layer_mode;
+        auto   layer_mode = handle->layer_mode;
+        Logger logger;
         if(layer_mode
            & (rocblas_layer_mode_log_trace | rocblas_layer_mode_log_bench
               | rocblas_layer_mode_log_profile))
@@ -79,63 +72,63 @@ namespace
 
             if(layer_mode & rocblas_layer_mode_log_trace)
             {
-                log_trace(handle,
-                          name,
-                          n,
-                          x,
-                          x_type_str,
-                          incx,
-                          y,
-                          y_type_str,
-                          incy,
-                          batch_count,
-                          result_type_str,
-                          ex_type_str);
+                logger.log_trace(handle,
+                                 name,
+                                 n,
+                                 x,
+                                 x_type_str,
+                                 incx,
+                                 y,
+                                 y_type_str,
+                                 incy,
+                                 batch_count,
+                                 result_type_str,
+                                 ex_type_str);
             }
 
             if(layer_mode & rocblas_layer_mode_log_bench)
             {
-                log_bench(handle,
-                          ROCBLAS_API_BENCH " -f",
-                          bench_name,
-                          "-n",
-                          n,
-                          "--a_type",
-                          x_type_str,
-                          "--incx",
-                          incx,
-                          "--b_type",
-                          y_type_str,
-                          "--incy",
-                          incy,
-                          "--batch_count",
-                          batch_count,
-                          "--c_type",
-                          result_type_str,
-                          "--compute_type",
-                          ex_type_str);
+                logger.log_bench(handle,
+                                 ROCBLAS_API_BENCH " -f",
+                                 bench_name,
+                                 "-n",
+                                 n,
+                                 "--a_type",
+                                 x_type_str,
+                                 "--incx",
+                                 incx,
+                                 "--b_type",
+                                 y_type_str,
+                                 "--incy",
+                                 incy,
+                                 "--batch_count",
+                                 batch_count,
+                                 "--c_type",
+                                 result_type_str,
+                                 "--compute_type",
+                                 ex_type_str);
             }
 
             if(layer_mode & rocblas_layer_mode_log_profile)
             {
-                log_profile(handle,
-                            name,
-                            "N",
-                            n,
-                            "a_type",
-                            x_type_str,
-                            "incx",
-                            incx,
-                            "b_type",
-                            y_type_str,
-                            "incy",
-                            incy,
-                            "batch_count",
-                            batch_count,
-                            "c_type",
-                            result_type_str,
-                            "compute_type",
-                            ex_type_str);
+                logger.log_profile(handle,
+                                   name,
+                                   "N",
+                                   n,
+                                   "a_type",
+                                   x_type_str,
+                                   "incx",
+                                   incx,
+                                   "b_type",
+                                   y_type_str,
+                                   "incy",
+                                   incy,
+                                   "batch_count",
+                                   batch_count,
+                                   "c_type",
+                                   result_type_str,
+                                   "compute_type",
+                                   ex_type_str);
             }
         }
 
